import 'package:medium_search/medium_search.dart';
import 'package:medium_search/src/exceptions/no_more_pages.dart';

import 'posts_search_dto.dart';

class PostsPage {
  /// Current page number.
  final int number;

  final String _q;
  final int _count;
  final Medium medium;

  /// Data Transfer Object.
  /// Contains all the data fetched.
  final PostsSearchDto dto;

  PostsPage(this.number, this._q, this._count, this.medium, this.dto);

  /// Get the posts.
  List<Value> get posts => dto.payload!.posts!;

  /// Is there more pages?
  get hasMore => dto.payload?.paging?.next != null;

  /// Get the next page.
  Future<PostsPage> get nextPage async {
    if (!hasMore) {
      throw NoMorePages();
    }

    return await medium.getPosts(
      _q,
      ignoredIds: dto.payload!.paging!.next!.ignoredIds!,
      page: number + 1,
      count: _count,
    );
  }
}
