import 'package:medium_search/medium_search.dart';
import 'package:medium_search/src/exceptions/no_more_pages.dart';

import 'users_search_dto.dart';

class UsersPage {
  /// Current page number.
  final int number;

  final String _q;
  final int _count;
  final Medium xMedium;

  /// Data Transfer Object.
  /// Contains all the data fetched.
  final UsersSearchDto dto;

  UsersPage(this.number, this._q, this._count, this.xMedium, this.dto);

  /// Get the users.
  List<User> get users => dto.payload!.users!;

  /// Is there more pages?
  get hasMore => dto.payload?.paging?.next != null;

  /// Get the next page.
  Future<UsersPage> get nextPage async {
    if (!hasMore) {
      throw NoMorePages();
    }

    return await xMedium.getUsers(
      _q,
      ignoredIds: dto.payload!.paging!.next!.ignoredIds!,
      page: number + 1,
      count: _count,
    );
  }
}
